@@ -1,5 +1,5 @@
 # Calendar::Schedule - Manage calendar schedules
-# (c) 2002-2020 Vlado Keselj http://web.cs.dal.ca/~vlado vlado@dnlp.ca
+# (c) 2002-2021 Vlado Keselj https://web.cs.dal.ca/~vlado vlado@dnlp.ca
 #               and contributing authors
 #
 # Some parts are updated with Starfish during development, such as the version
@@ -18,7 +18,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw(new);
 
 #<?echo "our \$VERSION = '$Meta->{version}';"!>#+
-our $VERSION = '1.21';#-
+our $VERSION = '1.22';#-
 
 # non-exported package globals
 use vars qw( $REweekday3 $REmonth3 $RE1st );
@@ -985,8 +985,8 @@ looks something like:
 
 The format "%A" would produce just the weekday name.
 
-Use $obj->{ShowDays} = 'workdays'; to display only work-days; i.e.,
-Monday to Friday.
+Use C<< $obj->{ShowDays} = 'workdays'; >> to display only work-days;
+i.e., Monday to Friday.
 
 The table rows include time labeles which are start times and end
 times of the events that happend to fall in the table time range, with
@@ -1415,7 +1415,7 @@ for the initial GitHub CI code.
 
 =head1 AUTHOR
 
-Copyright 2002-2020 Vlado Keselj (vlado@dnlp.ca http://vlado.ca)
+Copyright 2002-2021 Vlado Keselj (vlado@dnlp.ca http://vlado.ca)
 and the contributors (section CONTRIBUTORS).
 
 This script is provided "as is" without expressed or implied warranty.
